@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 Request Report Views
@@ -22,6 +21,7 @@ Request Report Views
 
 from schooltool.app.interfaces import ISchoolToolApplication
 from schooltool.export.export import RequestXLSReportDialog
+from schooltool.report.report import ReportLinkViewlet
 from schooltool.report.browser.report import RequestReportArchiveDialog
 
 
@@ -41,3 +41,7 @@ class RequestStudentCompetencyArchive(RequestReportArchiveDialog):
     @property
     def target(self):
         return ISchoolToolApplication(None)
+
+
+class GradebookArchiveLinkViewlet(ReportLinkViewlet):
+    pass
