@@ -20,6 +20,7 @@ Evolve database to generation 1.
 
 Sections get copies of skils instead of proxies.
 """
+import transaction, gc
 
 from zope.annotation.interfaces import IAnnotations
 from zope.app.generations.utility import findObjectsProviding, getRootFolder
@@ -89,7 +90,7 @@ def pick_section(score, sections):
     return None
 
 
-def evolveCourse(app, course):
+def evolveCourse(connection, app, course):
     int_ids = getUtility(IIntIds)
 
     annotations = IAnnotations(course)
@@ -122,8 +123,13 @@ def evolveCourse(app, course):
                 instructor_sections[instructor.__name__] = {}
             instructor_sections[instructor.__name__][sid] = section
 
+    transaction.savepoint(True)
+
     for course_skillset in courseskills.values():
         deploySkillSet(course_skillset, course_sections)
+        transaction.savepoint(True)
+        connection.cacheMinimize()
+        gc.collect()
 
     worksheet_cache = {}
 
@@ -160,6 +166,9 @@ def evolveCourse(app, course):
                         worksheet_cache[id(target_section)] = getSectionSkills(target_section)
                     reassignScoreSkill(worksheet_cache[id(target_section)],
                                        student_evaluations, score)
+            transaction.savepoint(True)
+            connection.cacheMinimize()
+            gc.collect()
 
 
 def evolve(context):
@@ -172,7 +181,7 @@ def evolve(context):
 
         for cc in app['schooltool.course.course'].values():
             for course in cc.values():
-                evolveCourse(app, course)
+                evolveCourse(context.connection, app, course)
 
     setSite(old_site)
 
