@@ -20,7 +20,6 @@ import itertools
 
 from persistent import Persistent
 import zope.lifecycleevent
-from zope.catalog.text import TextIndex
 from zope.container.btree import BTreeContainer
 from zope.container.contained import Contained
 from zope.component import adapts, adapter
@@ -32,7 +31,9 @@ from schooltool.app.interfaces import ISchoolToolApplication
 from schooltool.app.catalog import AttributeCatalog
 from zope.index.text.interfaces import ISearchableText
 from schooltool.cando import interfaces
+from schooltool.cando.skill import SearchableTextMixin
 from schooltool.cando.skill import URISkillSet
+from schooltool.cando.skill import setSearchableIndexes
 from schooltool.relationship import URIObject
 from schooltool.relationship import RelationshipSchema, RelationshipProperty
 from schooltool.relationship.interfaces import InvalidRelationship
@@ -550,14 +551,14 @@ def get_node_layer_titles(node):
 
 class NodeCatalog(AttributeCatalog):
 
-    version = '1.1 - update layers and layer titles'
+    version = '1.3 - add __name__ to text index'
     interface = interfaces.INode
     attributes = ('title', 'label', 'description',
                   'required', 'retired')
 
     def setIndexes(self, catalog):
         super(NodeCatalog, self).setIndexes(catalog)
-        catalog['text'] = TextIndex('getSearchableText', ISearchableText, True)
+        setSearchableIndexes(catalog)
         catalog['layers'] = ConvertingSetIndex(converter=get_node_layer_names)
         catalog['layer_titles'] = ConvertingSetIndex(converter=get_node_layer_titles)
 
@@ -565,7 +566,7 @@ class NodeCatalog(AttributeCatalog):
 getNodeCatalog = NodeCatalog.get
 
 
-class SearchableTextNode(object):
+class SearchableTextNode(SearchableTextMixin):
 
     adapts(interfaces.INode)
     implements(ISearchableText)
@@ -575,6 +576,7 @@ class SearchableTextNode(object):
 
     def getSearchableText(self):
         result = [
+            self.context.__name__,
             self.context.title,
             self.context.label or '',
             self.context.description or '',
